==> vtk-7.1.1-4-armv7h.pkg.tar.xz: vtk/vtkLightActor.java <==
// java wrapper for vtkLightActor object
//

package vtk;
import vtk.*;

public class vtkLightActor extends vtkProp3D
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLight_2(vtkLight id0);
  public void SetLight(vtkLight id0)
    { SetLight_2(id0); }

  private native long GetLight_3();
  public vtkLight GetLight() {
    long temp = GetLight_3();

    if (temp == 0) return null;
    return (vtkLight)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetClippingRange_4(double id0,double id1);
  public void SetClippingRange(double id0,double id1)
    { SetClippingRange_4(id0,id1); }

  private native void SetClippingRange_5(double id0[]);
  public void SetClippingRange(double id0[])
    { SetClippingRange_5(id0); }

  private native double[] GetClippingRange_6();
  public double[] GetClippingRange()
    { return GetClippingRange_6(); }

  private native int RenderOpaqueGeometry_7(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_7(id0); }

  private native int HasTranslucentPolygonalGeometry_8();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_8(); }

  private native void ReleaseGraphicsResources_9(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_9(id0); }

  private native int GetMTime_10();
  public int GetMTime()
    { return GetMTime_10(); }

  public vtkLightActor() { super(); }

  public vtkLightActor(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-armv7h.pkg.tar.xz: vtk/vtkLightActor.java <==
// java wrapper for vtkLightActor object
//

package vtk;
import vtk.*;

public class vtkLightActor extends vtkProp3D
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetLight_2(vtkLight id0);
  public void SetLight(vtkLight id0)
    { SetLight_2(id0); }

  private native long GetLight_3();
  public vtkLight GetLight() {
    long temp = GetLight_3();

    if (temp == 0) return null;
    return (vtkLight)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native void SetClippingRange_4(double id0,double id1);
  public void SetClippingRange(double id0,double id1)
    { SetClippingRange_4(id0,id1); }

  private native void SetClippingRange_5(double id0[]);
  public void SetClippingRange(double id0[])
    { SetClippingRange_5(id0); }

  private native double[] GetClippingRange_6();
  public double[] GetClippingRange()
    { return GetClippingRange_6(); }

  private native int RenderOpaqueGeometry_7(vtkViewport id0);
  public int RenderOpaqueGeometry(vtkViewport id0)
    { return RenderOpaqueGeometry_7(id0); }

  private native int HasTranslucentPolygonalGeometry_8();
  public int HasTranslucentPolygonalGeometry()
    { return HasTranslucentPolygonalGeometry_8(); }

  private native void ReleaseGraphicsResources_9(vtkWindow id0);
  public void ReleaseGraphicsResources(vtkWindow id0)
    { ReleaseGraphicsResources_9(id0); }

  private native int GetMTime_10();
  public int GetMTime()
    { return GetMTime_10(); }

  public vtkLightActor() { super(); }

  public vtkLightActor(long id) { super(id); }
  public native long   VTKInit();

}
